.. _learn:

Learn
=====

How to install DeLU?
--------------------

For installation instructions, see :ref:`Installation <installation>`.

What is Reference?
----------------------

Reference (see the sidebar) provides API specification, tutorials and usage examples.
It is the main source of knowledge about the library.

How to learn DeLU?
------------------

DeLU is a toolbox, not a framework, so you can learn things and
start using them in any order. If you want to explore the library by yourself,
just browse the Reference.

Also, we provide some examples, where you can do ``Ctrl+F "delu."`` and see how DeLU can be used:

- `(Computer Vision) Classification <https://github.com/Yura52/delu/blob/main/examples/mnist.py>`_
